%bcond_without java

# the zic(8) and zdump(8) manpages are already in man-pages
%define build_manpages 0

Summary:	Time Zone Database
Name:		timezone
Epoch:		6
Version:	2018e
Release:	1
License:	BSD
Group:		System/Base
Url:		http://www.iana.org/time-zones
Source0:	ftp://ftp.iana.org/tz/releases/tzdata%{version}.tar.gz
Source1:	ftp://ftp.iana.org/tz/releases/tzcode%{version}.tar.gz
Source2:	javazic.tar.gz
Source3:	timezone.rpmlintrc
Patch1:		tzdata-extra-tz-links.patch
Patch2:		javazic-fixup.patch
Patch3:		javazic-exclusion-fix.patch
BuildRequires:	gawk
Provides:	tzdata = %{EVRD}

%description
This package contains data files with rules for various timezones
around the world.

%files
%doc README
%doc tz-art.html
%{_sbindir}/zdump
%{_sbindir}/zic
%if %{build_manpages}
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%endif
%dir %{_datadir}/zoneinfo
%{_datadir}/zoneinfo/*

%pretrans
if [ -e %{_datadir}/zoneinfo/posix -a ! -L %{_datadir}/zoneinfo/posix ]; then
	rm -rf %{_datadir}/zoneinfo/posix
fi

#----------------------------------------------------------------------------

%if %{with java}
%package java
Summary:	Timezone data for Java
Group:		System/Base
Provides:	tzdata-java = %{EVRD}
BuildRequires:	java-rpmbuild
BuildRequires:	java-devel

%description java
This package contains timezone information for use by Java runtimes.

%files java
%doc README
%{_datadir}/javazi
%endif

#----------------------------------------------------------------------------

%prep
%setup -q -c -a 1
%patch1 -p1 -b .extra-tz-links

%if %{with java}
mkdir javazic
tar xf %{SOURCE2} -C javazic
pushd javazic
%patch2 -p0 -b .javazic-fixup
%patch3
# Hack alert! sun.tools may be defined and installed in the
# VM. In order to guarantee that we are using IcedTea/OpenJDK
# for creating the zoneinfo files, rebase all the packages
# from "sun." to "rht.". Unfortunately, gcj does not support
# any of the -Xclasspath options, so we must go this route
# to ensure the greatest compatibility.
mv sun rht
for f in `find . -name '*.java'`; do
	sed -i -e 's:sun\.tools\.:rht.tools.:g'\
		-e 's:sun\.util\.:rht.util.:g' $f
done
popd

# Create zone.info entries for deprecated zone names (#40184)
	chmod +w zone.tab
		echo '# zone info for backward zone names' > zone.tab.new
		while read link cur old x; do
			case $link-${cur+cur}-${old+old}${x:+X} in
				Link-cur-old)
					awk -v cur="$cur" -v old="$old" \
						'!/^#/ && $3 == cur { sub(cur,old); print }' \
							zone.tab || echo ERROR ;;
					Link-*)
						echo 'Error processing backward entry for zone.tab'
						exit 1 ;;
			esac
		done < backward >> zone.tab.new
		if grep -q '^ERROR' zone.tab.new || ! cat zone.tab.new >> zone.tab; then
			echo "Error adding backward entries to zone.tab"
			exit 1
		fi
		rm -f zone.tab.new
%endif

%build
# (tpg) fix build
sed -i -e "s/$(AR) -rc/$(AR) r/g" Makefile*

%make TZDIR=%{_datadir}/zoneinfo CFLAGS="%{optflags} -std=gnu99"

%if %{with java}
pushd javazic
%{javac} -source 1.5 -target 1.5 -classpath . `find . -name \*.java`
popd
%{java} -classpath javazic/ rht.tools.javazic.Main -V %{version} \
	-d zoneinfo/java \
	africa antarctica asia australasia europe northamerica pacificnew \
	southamerica backward etcetera systemv \
	javazic/tzdata_jdk/gmt javazic/tzdata_jdk/jdk11_backward
%endif

%install
make TOPDIR=%{buildroot} \
	TZDIR=%{buildroot}%{_datadir}/zoneinfo \
	ETCDIR=%{buildroot}%{_sbindir} \
	install

rm -f %{buildroot}%{_datadir}/zoneinfo-posix
ln -s . %{buildroot}%{_datadir}/zoneinfo/posix
mv %{buildroot}%{_datadir}/zoneinfo-leaps %{buildroot}%{_datadir}/zoneinfo/right
mv %{buildroot}%{_bindir}/zdump %{buildroot}%{_sbindir}/zdump

# nuke unpackaged files
rm -f %{buildroot}%{_datadir}/zoneinfo/localtime
rm -f %{buildroot}%{_bindir}/tzselect
rm -f %{buildroot}%{_sysconfdir}/localtime
rm -rf %{buildroot}/usr/{lib,man}

%if !%{build_manpages}
rm -rf %{buildroot}%{_mandir}
%endif

%if %{with java}
cp -a zoneinfo/java %{buildroot}%{_datadir}/javazi
%endif

# install man pages
%if %{build_manpages}
mkdir -p %{buildroot}%{_mandir}/man8
for f in zic zdump; do
install -m 644 $f.8 %{buildroot}%{_mandir}/man8/
done
%endif

%changelog
